Download the neural network model used by Dawnn.
download_model.Rd`download_model()' downloads the neural network model used by Dawnn, which is too large to be bundled with the package. This function must be used once before run_dawnn() can be executed. After this, the path to the model can be passed to this function.
Usage
download_model(
model_url = NULL,
model_file_path = NULL,
download_method = "auto",
download_timeout = 600
)