Generate a null distribution of P(Condition_1) estimates.
generate_null_dist.Rdgenerate_null_dist() shuffles the sample labels three times
and returns the estimates of P(Condition_1) for each shuffled dataset.
Arguments
- cells
Seurat object containing the dataset.
- model
Loaded neural network model to use.
- label_names
String containing the name of the meta.data slot in `cells' containing the labels of each cell.
- label_1
String containing the name of one of the labels.
- label_2
String containing the name of the other label.
- verbosity
Integer how much output to print. 0: silent; 1: normal output; 2: display messages from predict() function.
- da_mode
String containing the type of differential abundance being seeked, either "lda" (local DA) or "gda" (global DA).